tidytree-package: tidytree: A Tidy Tool for Phylogenetic Tree Data Manipulation

tidytree-packageR Documentation

tidytree: A Tidy Tool for Phylogenetic Tree Data Manipulation

Description

Phylogenetic trees contain components such as nodes, edges, branches, and associated data. As the core data manipulation tool in the 'ggtree' ecosystem, 'tidytree' provides tools for converting tree objects to tidy data frames and tidy interfaces for manipulating, analyzing, and visualizing tree data.

Author(s)

Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID) [copyright holder]

Authors:

Other contributors:

See Also

Useful links:


tidytree documentation built on July 3, 2026, 1:08 a.m.