| tidytree-package | R Documentation |
Phylogenetic trees contain components such as nodes, edges, branches, and associated data. As the core data manipulation tool in the 'ggtree' ecosystem, 'tidytree' provides tools for converting tree objects to tidy data frames and tidy interfaces for manipulating, analyzing, and visualizing tree data.
Maintainer: Guangchuang Yu guangchuangyu@gmail.com (ORCID) [copyright holder]
Authors:
Guangchuang Yu guangchuangyu@gmail.com (ORCID) [copyright holder]
Other contributors:
Bradley Jones brj1@sfu.ca [contributor]
Zebulun Arendsee zbwrnz@gmail.com [contributor]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.